@@ -249,6 +249,12 @@ class status(WithTargets):
     
     reads_remote = False
     writes_remote = False
+    
+class revert(WithTargets):
+    """Revert a set of files"""
+    
+    reads_remote = False
+    writes_remote = False
 
 class StatusOutput(object):
     """Output specific to a status command."""
