@@ -108,6 +108,18 @@ class status(HgCommand):
     def process_output(self, returncode, stdout):
         return StatusOutput(returncode, stdout)
     
+class revert(HgCommand):
+    reads_remote = False
+    writes_remote = False
+    
+    def command_parts(self):
+        parts = super(revert, self).command_parts()
+        parts.insert(1, "--no-backup")
+        if not self.targets:
+            parts.append("-a")
+        return parts
+    
+
 class HgDialect(object):
     
     name = "hg"
